@@ -24,12 +24,8 @@ class Level(CompareCondition):
 
 class DateJoined(CompareCondition):
 
-    @staticmethod
-    def timestamp2datetime(timestamp):
-        return datetime.datetime.strptime(timestamp, "%m/%d/%Y")
-
     condstr = 'DATE_JOINED'
-    cast_operand = timestamp2datetime
+    cast_operand = lambda self, timestamp: datetime.datetime.strptime(timestamp, "%m/%d/%Y")
 
     @classmethod
     def operators(cls):
